@@ -1,4 +1,8 @@
-# Copyright (C) 2012-2014 W. Trevor King <wking@tremily.us>
+# Copyright (C) 2012-2019 Adam Mokhtari <2553423+uutari@users.noreply.github.com>
+#                         François Boulogne <fboulogne sciunto org>
+#                         Léo Gaspard <leo@gaspard.io>
+#                         Profpatsch <mail@profpatsch.de>
+#                         W. Trevor King <wking@tremily.us>
 #
 # This file is part of rss2email.
 #
@@ -21,33 +25,23 @@ import logging as _logging
 import sys as _sys
 
 
-__version__ = '3.9'
-__url__ = 'https://github.com/wking/rss2email'
-__author__ = 'W. Trevor King'
+__version__ = '3.11'
+__url__ = 'https://github.com/rss2email/rss2email'
+__author__ = 'The rss2email maintainers'
 __email__ = 'rss2email@tremily.us'
 __copyright__ = '(C) 2004 Aaron Swartz. GNU GPL 2 or 3.'
-__contributors__ = [
-    'Aaron Swartz (original author)',
-    'Brian Lalor',
-    'Dean Jackson',
-    'Eelis van der Weegen',
-    'Erik Hetzner',
-    'Etienne Millon',
-    'George Saunders',
-    'Joey Hess',
-    'Lindsey Smith (lindsey@allthingsrss.com)',
-    'Marcel Ackermann (http://www.DreamFlasher.de)',
-    "Martin 'Joey' Schulze",
-    'Matej Cepl',
-    'W. Trevor King',
-    ]
 
 LOG = _logging.getLogger('rss2email')
 LOG.addHandler(_logging.StreamHandler())
 LOG.setLevel(_logging.ERROR)
 
 
-if _sys.version_info < (3, 2):
+min_python_version = (3, 4)
+if _sys.version_info < min_python_version:
     raise ImportError(
-        "rss2email requires Python 3.2, but you're using:\n{}".format(
-            _sys.version))
+        "rss2email requires Python {maj}.{min} or newer, but you're using:\n{got}"
+        .format(
+            maj=min_python_version[0],
+            min=min_python_version[1],
+            got=_sys.version
+        ))
