@@ -1,4 +1,9 @@
-# Copyright (C) 2012-2014 W. Trevor King <wking@tremily.us>
+# Copyright (C) 2012-2019 Etienne Millon <me@emillon.org>
+#                         Gregory Soutade <gregory@soutade.fr>
+#                         Kaashif Hymabaccus <kaashif@kaashif.co.uk>
+#                         Martin Monperrus <monperrus@users.noreply.github.com>
+#                         Profpatsch <mail@profpatsch.de>
+#                         W. Trevor King <wking@tremily.us>
 #
 # This file is part of rss2email.
 #
@@ -17,20 +22,24 @@
 """rss2email commands
 """
 
+import os as _os
 import re as _re
 import sys as _sys
 import xml.dom.minidom as _minidom
 import xml.sax.saxutils as _saxutils
+import urllib as _urllib
+import time as _time
 
 from . import LOG as _LOG
 from . import error as _error
 
-
 def new(feeds, args):
     "Create a new feed database."
     if args.email:
         _LOG.info('set the default target email to {}'.format(args.email))
         feeds.config['DEFAULT']['to'] = args.email
+    if _os.path.exists(feeds.configfiles[-1]):
+        raise _error.ConfigAlreadyExistsError(feeds=feeds)
     feeds.save()
 
 def email(feeds, args):
@@ -55,13 +64,30 @@ def run(feeds, args):
     if not args.index:
         args.index = range(len(feeds))
     try:
+        # How long (in seconds) to sleep between running feeds with
+        # the same server.
+        interval = float(feeds.config['DEFAULT']['same-server-fetch-interval'])
+
+        # We use the domain name to determine if we are fetching from
+        # the same server twice in a row.
+        last_server = "example.com"
         for index in args.index:
             feed = feeds.index(index)
+            # to debug feeds that timeout, run "r2e -VV run"
+            _LOG.info('refreshing feed {}'.format(feed))
             if feed.active:
+                current_server = _urllib.parse.urlparse(feed.url).netloc
                 try:
+                    if last_server == current_server:
+                        _LOG.info('fetching from server {current_server} again, sleeping for {interval}s'.format(
+                            current_server = current_server,
+                            interval = interval
+                        ))
+                        _time.sleep(interval)
                     feed.run(send=args.send)
                 except _error.RSS2EmailError as e:
                     e.log()
+                last_server = current_server
     finally:
         feeds.save()
 
