@@ -1,17 +1,26 @@
-# Copyright (C) 2004-2014 Aaron Swartz
+# Copyright (C) 2004-2019 Aaron Swartz
+#                         Anders Damsgaard <anders@adamsgaard.dk>
+#                         Andrey Zelenchuk <azelenchuk@parallels.com>
 #                         Brian Lalor
 #                         Dean Jackson
 #                         Dmitry Bogatov <KAction@gnu.org>
 #                         Erik Hetzner
 #                         Etienne Millon <me@emillon.org>
+#                         François Boulogne <fboulogne sciunto org>
 #                         George Saunders <georgesaunders@gmail.com>
+#                         Jakub Wilk <jwilk@jwilk.net>
 #                         Joey Hess
+#                         Kaashif Hymabaccus <kaashif@kaashif.co.uk>
 #                         Lindsey Smith <lindsey.smith@gmail.com>
 #                         Marcel Ackermann
 #                         Martin 'Joey' Schulze
+#                         Martin Monperrus <monperrus@users.noreply.github.com>
 #                         Matej Cepl
+#                         Profpatsch <mail@profpatsch.de>
 #                         Thiago Coutinho <root@thiagoc.net>
+#                         Thibaut Girka <thib@sitedethib.com>
 #                         W. Trevor King <wking@tremily.us>
+#                         Yannik Sembritzki <yannik@sembritzki.me>
 #
 # This file is part of rss2email.
 #
@@ -35,7 +44,6 @@ import configparser as _configparser
 
 import html2text as _html2text
 
-
 class Config (_configparser.ConfigParser):
     def __init__(self, dict_type=_collections.OrderedDict,
                  interpolation=_configparser.ExtendedInterpolation(),
@@ -65,8 +73,10 @@ CONFIG['DEFAULT'] = _collections.OrderedDict((
         ### Addressing
         # The email address messages are from by default
         ('from', 'user@rss2email.invalid'),
+        # The User-Agent default string (rss2email __VERSION__ and __URL__ is replaced)
+        ('user-agent', 'rss2email/__VERSION__ (__URL__)'),
         # Transfer-Encoding. For local mailing it is safe and
-        # convient to use 8bit.
+        # convenient to use 8bit.
         ('use-8bit', str(False)),
         # True: Only use the 'from' address.
         # False: Use the email address specified by the feed, when possible.
@@ -76,8 +86,8 @@ CONFIG['DEFAULT'] = _collections.OrderedDict((
         ('use-publisher-email', str(False)),
         # If empty, only use the feed email address rather than
         # friendly name plus email address.  Available attributes may
-        # include 'feed', 'feed-title', 'author', and 'publisher', but
-        # only 'feed' is guaranteed.
+        # include 'feed', 'feed-name', 'feed-url', 'feed-title', 'author', and
+        # 'publisher', but only 'feed', 'feed-name', and 'feed-url' are guaranteed.
         ('name-format', '{feed-title}: {author}'),
         # Set this to default To email addresses.
         ('to', ''),
@@ -87,6 +97,8 @@ CONFIG['DEFAULT'] = _collections.OrderedDict((
         ('proxy', ''),
         # Set the timeout (in seconds) for feed server response
         ('feed-timeout', str(60)),
+        # Set the time (in seconds) to sleep between fetches from the same server
+        ('same-server-fetch-interval', str(0)),
 
         ### Processing
         # True: Fetch, process, and email feeds.
@@ -123,7 +135,7 @@ CONFIG['DEFAULT'] = _collections.OrderedDict((
         # Example: post-process = 'rss2email.post_process.downcase downcase_message'
         ('post-process', ''),
         # User processing hooks for digest messages.  If 'digest' is
-        # enabled, the usual 'post-process' hook gets to massage the
+        # enabled, the usual 'post-process' hook gets to message the
         # per-entry messages, but this hook is called with the full
         # digest message before it is mailed.
         # Example: digest-post-process = 'rss2email.post_process.downcase downcase_message'
@@ -191,19 +203,22 @@ CONFIG['DEFAULT'] = _collections.OrderedDict((
         ('smtp-auth', str(False)),      # set to True to use SMTP AUTH
         ('smtp-username', 'username'),  # username for SMTP AUTH
         ('smtp-password', 'password'),  # password for SMTP AUTH
-        ('smtp-server', 'smtp.yourisp.net:25'),
+        ('smtp-server', 'smtp.example.net'),
+        ('smtp-port', '465'),
         ('smtp-ssl', str(False)),       # Connect to the SMTP server using SSL
-        ('smtp-ssl-protocol', 'SSLv3'), # TLS/SSL version to use on STARTTLS when not using 'smtp-ssl'
         # IMAP configuration
         ('imap-auth', str(False)),      # set to True to use IMAP auth.
         ('imap-username', 'username'),  # username for IMAP authentication
         ('imap-password', 'password'),  # password for IMAP authentication
-        ('imap-server', 'imap.yourisp.net'),
+        ('imap-server', 'imap.example.net'),
         ('imap-port', str(143)),
         ('imap-ssl', str(False)),       # connect to the IMAP server using SSL
         ('imap-mailbox', 'INBOX'),      # where we should store new messages
+        # Maildir configuration
+        ('maildir-path', '~/Maildir'),
+        ('maildir-mailbox', 'INBOX'),
 
         ### Miscellaneous
         # Verbosity (one of 'error', 'warning', 'info', or 'debug').
-        ('verbose', 'warning'),
+        ('verbose', 'info'),
         ))
