@@ -1,10 +1,15 @@
 # -*- encoding: utf-8 -*-
 #
-# Copyright (C) 2012-2014 Arun Persaud <apersaud@lbl.gov>
+# Copyright (C) 2012-2018 Arun Persaud <apersaud@lbl.gov>
 #                         Dmitry Bogatov <KAction@gnu.org>
 #                         George Saunders <georgesaunders@gmail.com>
+#                         Jeff Backus <jeff@jsbackus.com>
+#                         Mátyás Jani <jzombi@gmail.com>
+#                         Profpatsch <mail@profpatsch.de>
 #                         Thiago Coutinho <root@thiagoc.net>
+#                         Thibaut Girka <thib@sitedethib.com>
 #                         W. Trevor King <wking@tremily.us>
+#                         Yannik Sembritzki <yannik@sembritzki.me>
 #
 # This file is part of rss2email.
 #
@@ -32,6 +37,8 @@ from email.header import Header as _Header
 from email.mime.text import MIMEText as _MIMEText
 from email.utils import formataddr as _formataddr
 from email.utils import parseaddr as _parseaddr
+import mailbox as _mailbox
+from email.utils import getaddresses as _getaddresses
 import imaplib as _imaplib
 import io as _io
 import smtplib as _smtplib
@@ -39,6 +46,7 @@ import ssl as _ssl
 import subprocess as _subprocess
 import sys as _sys
 import time as _time
+import os as _os
 
 from . import LOG as _LOG
 from . import config as _config
@@ -107,7 +115,12 @@ def get_message(sender, recipient, subject, body, content_type,
 
     # Split real name (which is optional) and email address parts
     sender_name,sender_addr = _parseaddr(sender)
-    recipient_name,recipient_addr = _parseaddr(recipient)
+    recipient_list = []
+    for recipient_name, recipient_addr in _getaddresses([recipient]):
+        recipient_encoding = guess_encoding(recipient_name, encodings)
+        recipient_name = str(_Header(recipient_name, recipient_encoding).encode())
+        recipient_addr.encode('ascii')
+        recipient_list.append(_formataddr((recipient_name, recipient_addr)))
 
     sender_encoding = guess_encoding(sender_name, encodings)
     recipient_encoding = guess_encoding(recipient_name, encodings)
@@ -117,16 +130,14 @@ def get_message(sender, recipient, subject, body, content_type,
     # We must always pass Unicode strings to Header, otherwise it will
     # use RFC 2047 encoding even on plain ASCII strings.
     sender_name = str(_Header(sender_name, sender_encoding).encode())
-    recipient_name = str(_Header(recipient_name, recipient_encoding).encode())
 
     # Make sure email addresses do not contain non-ASCII characters
     sender_addr.encode('ascii')
-    recipient_addr.encode('ascii')
 
     # Create the message ('plain' stands for Content-Type: text/plain)
     message = _MIMEText(body, content_type, body_encoding)
     message['From'] = _formataddr((sender_name, sender_addr))
-    message['To'] = _formataddr((recipient_name, recipient_addr))
+    message['To'] = ', '.join(recipient_list)
     message['Subject'] = _Header(subject, subject_encoding)
     if config.getboolean(section, 'use-8bit'):
         del message['Content-Transfer-Encoding']
@@ -143,37 +154,42 @@ def smtp_send(sender, recipient, message, config=None, section='DEFAULT'):
     if config is None:
         config = _config.CONFIG
     server = config.get(section, 'smtp-server')
+    # Adding back in support for 'server:port'
+    pos = server.find(':')
+    if 0 <= pos:
+        # Strip port out of server name
+        port = int(server[pos+1:])
+        server = server[:pos]
+    else:
+        port = config.getint(section, 'smtp-port')
+
     _LOG.debug('sending message to {} via {}'.format(recipient, server))
     ssl = config.getboolean(section, 'smtp-ssl')
-    if ssl:
-        smtp = _smtplib.SMTP_SSL()
-    else:
-        smtp = _smtplib.SMTP()
+    smtp_auth = config.getboolean(section, 'smtp-auth')
     try:
-        smtp.connect(server)
+        if ssl or smtp_auth:
+            context = _ssl.create_default_context()
+        if ssl:
+            smtp = _smtplib.SMTP_SSL(host=server, port=port, context=context)
+        else:
+            smtp = _smtplib.SMTP(host=server, port=port)
     except KeyboardInterrupt:
         raise
     except Exception as e:
         raise _error.SMTPConnectionError(server=server) from e
-    if config.getboolean(section, 'smtp-auth'):
+    if smtp_auth:
         username = config.get(section, 'smtp-username')
         password = config.get(section, 'smtp-password')
         try:
             if not ssl:
-                protocol_name = config.get(section, 'smtp-ssl-protocol')
-                protocol = getattr(_ssl, 'PROTOCOL_{}'.format(protocol_name))
-                try:
-                    smtp.starttls(context=_ssl.SSLContext(protocol=protocol))
-                except TypeError:
-                    # Python 3.2 or earlier
-                    smtp.starttls()
+                smtp.starttls(context=context)
             smtp.login(username, password)
         except KeyboardInterrupt:
             raise
         except Exception as e:
             raise _error.SMTPAuthenticationError(
                 server=server, username=username)
-    smtp.send_message(message, sender, [recipient])
+    smtp.send_message(message, sender, recipient.split(','))
     smtp.quit()
 
 def imap_send(message, config=None, section='DEFAULT'):
@@ -207,6 +223,14 @@ def imap_send(message, config=None, section='DEFAULT'):
     finally:
         imap.logout()
 
+def maildir_send(message, config=None, section='DEFAULT'):
+    if config is None:
+        config = _config.CONFIG
+    path = config.get(section, 'maildir-path')
+    mailbox = config.get(section, 'maildir-mailbox')
+    maildir = _mailbox.Maildir(_os.path.join(path, mailbox))
+    maildir.add(message)
+
 def _decode_header(header):
     """Decode RFC-2047-encoded headers to Unicode strings
 
@@ -228,8 +252,6 @@ def _decode_header(header):
             chunks.append(chunk)
         else:
             chunks.append(str(chunk, charset))
-    if _sys.version_info < (3, 3):  # Python 3.2 and older
-        return ' '.join(chunks)  # http://bugs.python.org/issue1079
     return ''.join(chunks)
 
 def _flatten(message):
@@ -301,7 +323,9 @@ def _flatten(message):
     b"\x00Y\x00o\x00u\x00'\x00r\x00e\x00 \x00g\x00r\x00e\x00a\x00t\x00,\x00 \x00\x96\x03\xb5\x03\xcd\x03\xc2\x03!\x00\n\x00"
     """
     bytesio = _io.BytesIO()
-    generator = _BytesGenerator(bytesio)  # use policies for Python >=3.3
+    # TODO: use policies argument instead of policy set in `message`
+    # see https://docs.python.org/3.5/library/email.generator.html?highlight=bytesgenerator#email.generator.BytesGenerator
+    generator = _BytesGenerator(bytesio)
     try:
         generator.flatten(message)
     except UnicodeEncodeError as e:
@@ -349,6 +373,8 @@ def send(sender, recipient, message, config=None, section='DEFAULT'):
             config=config, section=section)
     elif protocol == 'imap':
         imap_send(message=message, config=config, section=section)
+    elif protocol == 'maildir':
+        maildir_send(message=message, config=config, section=section)
     else:
         sendmail_send(
             sender=sender, recipient=recipient, message=message,
