@@ -1,4 +1,6 @@
-# Copyright (C) 2012-2014 W. Trevor King <wking@tremily.us>
+# Copyright (C) 2012-2018 Etienne Millon <me@emillon.org>
+#                         Profpatsch <mail@profpatsch.de>
+#                         W. Trevor King <wking@tremily.us>
 #
 # This file is part of rss2email.
 #
@@ -258,3 +260,9 @@ class OPMLReadError (RSS2EmailError):
     def __init__(self, **kwargs):
         message = 'error reading OPML'
         super(OPMLReadError, self).__init__(message=message, **kwargs)
+
+
+class ConfigAlreadyExistsError (FeedsError):
+    def __init__(self, feeds=None):
+        message = 'configuration file already exists'
+        super().__init__(feeds=feeds, message=message)
