@@ -1,18 +1,27 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) 2004-2014 Aaron Swartz
+# Copyright (C) 2004-2019 Aaron Swartz
+#                         Anders Damsgaard <anders@adamsgaard.dk>
+#                         Andrey Zelenchuk <azelenchuk@parallels.com>
 #                         Brian Lalor
 #                         Dean Jackson
 #                         Dennis Keitzel <github@pinshot.net>
+#                         Emil Oppeln-Bronikowski <emil@fuse.pl>
 #                         Erik Hetzner
 #                         Etienne Millon <me@emillon.org>
 #                         George Saunders <georgesaunders@gmail.com>
+#                         Gregory Soutade <gregory@soutade.fr>
 #                         J. Lewis Muir <jlmuir@imca-cat.org>
+#                         Jakub Wilk <jwilk@jwilk.net>
 #                         Joey Hess
+#                         Kaashif Hymabaccus <kaashif@kaashif.co.uk>
 #                         Lindsey Smith <lindsey.smith@gmail.com>
 #                         Marcel Ackermann
 #                         Martin 'Joey' Schulze
+#                         Martin Monperrus <monperrus@users.noreply.github.com>
 #                         Matej Cepl
+#                         Profpatsch <mail@profpatsch.de>
 #                         W. Trevor King <wking@tremily.us>
+#                         shan3141 <xpoh434@users.noreply.github.com>
 #
 # This file is part of rss2email.
 #
@@ -48,6 +57,7 @@ import xml.sax.saxutils as _saxutils
 
 import feedparser as _feedparser
 import html2text as _html2text
+import html as _html
 
 from . import __url__
 from . import __version__
@@ -58,8 +68,6 @@ from . import error as _error
 from . import util as _util
 
 
-_USER_AGENT = 'rss2email/{} ({})'.format(__version__, __url__)
-_feedparser.USER_AGENT = _USER_AGENT
 _urllib_request.install_opener(_urllib_request.build_opener())
 _SOCKET_ERRORS = []
 for e in ['error', 'herror', 'gaierror']:
@@ -216,6 +224,8 @@ class Feed (object):
             self.url = url
         if to:
             self.to = to
+        self.user_agent = self.user_agent.replace('__VERSION__', __version__)
+        self.user_agent = self.user_agent.replace('__URL__', __url__)
 
     def __str__(self):
         return '{} ({} -> {})'.format(self.name, self.url, self.to)
@@ -224,7 +234,7 @@ class Feed (object):
         return '<Feed {}>'.format(str(self))
 
     def __getstate__(self):
-        "Save dyamic attributes"
+        "Save dynamic attributes"
         return dict(
             (key,getattr(self,key)) for key in self._dynamic_attributes)
 
@@ -373,9 +383,8 @@ class Feed (object):
             _LOG.info('redirect {} from {} to {}'.format(
                     self.name, self.url, parsed['url']))
             self.url = parsed['url']
-        elif status not in [200, 302, 304]:
+        elif status not in [200, 302, 304, 307]:
             raise _error.HTTPError(status=status, feed=self)
-
         http_headers = parsed.get('headers', {})
         if http_headers:
             _LOG.debug('HTTP headers: {}'.format(http_headers))
@@ -394,7 +403,7 @@ class Feed (object):
         if version:
             _LOG.debug('feed version {}'.format(version))
         else:
-            _LOG.warning('unrecognized version: {}'.format(self))
+            _LOG.debug('unrecognized version: {}'.format(self))
             warned = True
 
         exc = parsed.get('bozo_exception', None)
@@ -423,6 +432,9 @@ class Feed (object):
             _LOG.warning(
                 'incorrectly declared encoding: {}: {}'.format(exc, self))
             warned = True
+        elif (parsed.bozo and isinstance(exc, _feedparser.NonXMLContentType)):
+            _LOG.warning('non XML Content-Type: {}: {}'.format(exc, self))
+            warned = True
         elif parsed.bozo or exc:
             if exc is None:
                 exc = "can't process"
@@ -433,7 +445,7 @@ class Feed (object):
             status in [200, 302] and
             not parsed.entries and
             not version):
-            raise _error.ProcessingError(parsed=parsed, feed=feed)
+            raise _error.ProcessingError(parsed=parsed, feed=self)
 
     def _html2text(self, html, baseurl='', default=None):
         self.config.setup_html2text(section=self.section)
@@ -445,31 +457,28 @@ class Feed (object):
             raise
 
     def _process_entry(self, parsed, entry):
-        id_ = self._get_entry_id(entry)
-        # If .trust_guid isn't set, we get back hashes of the content.
-        # Instead of letting these run wild, we put them in context
-        # by associating them with the actual ID (if it exists).
-        guid = entry.get('id', id_)
-        if isinstance(guid, dict):
-            guid = guid.values()[0]
+        # get_entry_id is the unique method that encapsulates where the strategy for getting the id is set
+        guid = self._get_entry_id(entry)
         if guid in self.seen:
-            if self.seen[guid]['id'] == id_:
-                _LOG.debug('already seen {}'.format(id_))
-                return  # already seen
+            _LOG.debug('already seen {}'.format(guid))
+            return  # already seen
+        _LOG.debug('not seen {}'.format(guid))
         sender = self._get_entry_email(parsed=parsed, entry=entry)
         subject = self._get_entry_title(entry)
+
         extra_headers = _collections.OrderedDict((
                 ('Date', self._get_entry_date(entry)),
                 ('Message-ID', '<{}@dev.null.invalid>'.format(_uuid.uuid4())),
-                ('User-Agent', _USER_AGENT),
+                ('User-Agent', self.user_agent),
                 ('X-RSS-Feed', self.url),
-                ('X-RSS-ID', id_),
+                ('X-RSS-ID', guid),
                 ('X-RSS-URL', self._get_entry_link(entry)),
                 ('X-RSS-TAGS', self._get_entry_tags(entry)),
                 ))
-        for k,v in extra_headers.items():  # remove empty tags, etc.
-            if v is None:
-                extra_headers.pop(k)
+        # remove empty tags, etc.
+        keys = {k for k, v in extra_headers.items() if v is None}
+        for key in keys:
+            extra_headers.pop(key)
         if self.bonus_header:
             for header in self.bonus_header.splitlines():
                 if ':' in header:
@@ -496,7 +505,7 @@ class Feed (object):
             extra_headers=extra_headers,
             config=self.config,
             section=self.section)
-        return (guid, id_, sender, message)
+        return (guid, guid, sender, message)
 
     def _get_entry_id(self, entry):
         """Get best ID from an entry."""
@@ -581,6 +590,8 @@ class Feed (object):
             return ''
         data = {
             'feed': self,
+            'feed-name': self.name,
+            'feed-url': self.url,
             'feed-title': '<feed title>',
             'author': '<author>',
             'publisher': '<publisher>',
@@ -595,7 +606,7 @@ class Feed (object):
         if 'name' in feed.get('publisher_detail', []):
             data['publisher'] = feed.publisher_detail.name
         name = self.name_format.format(**data)
-        return _html2text.unescape(name)
+        return _html.unescape(name)
 
     def _validate_email(self, email, default=None):
         """Do a basic quality check on email address
@@ -624,7 +635,7 @@ class Feed (object):
     def _get_entry_address(self, parsed, entry):
         """Get the best From email address ('<jdoe@a.com>')
 
-        If the best guess isn't well-formed (something@somthing.com),
+        If the best guess isn't well-formed (something@something.com),
         use `self.from_email` instead.
         """
         if self.force_from:
@@ -864,7 +875,7 @@ class Feed (object):
         digest['To'] = self.to  # TODO: _Header(), _formataddr((recipient_name, recipient_addr))
         digest['Subject'] = 'digest for {}'.format(self.name)
         digest['Message-ID'] = '<{}@dev.null.invalid>'.format(_uuid.uuid4())
-        digest['User-Agent'] = _USER_AGENT
+        digest['User-Agent'] = self.user_agent
         digest['X-RSS-Feed'] = self.url
         return digest
 
