@@ -1,5 +1,7 @@
-# Copyright (C) 2013 Arun Persaud <apersaud@lbl.gov>
-#                    W. Trevor King <wking@tremily.us>
+# Copyright (C) 2013-2018 Arun Persaud <apersaud@lbl.gov>
+#                         Etienne Millon <me@emillon.org>
+#                         Profpatsch <mail@profpatsch.de>
+#                         W. Trevor King <wking@tremily.us>
 #
 # This file is part of rss2email.
 #
@@ -62,9 +64,10 @@ process
 
 # import modules you need
 from bs4 import BeautifulSoup
+import rss2email.email
 
 
-def pretty(message):
+def pretty(feed, parsed, entry, guid, message):
     """Use BeautifulSoup to pretty-print the html
 
     A very simple function that decodes the entry into a unicode
@@ -93,7 +96,7 @@ def pretty(message):
 
 
 def process(feed, parsed, entry, guid, message):
-    message = pretty(message)
+    message = pretty(feed, parsed, entry, guid, message)
     # you could add several filters in here if you want to
 
     # we need to return the message, if we return False,
