@@ -1,4 +1,5 @@
-# Copyright (C) 2012-2013 W. Trevor King <wking@tremily.us>
+# Copyright (C) 2012-2018 Profpatsch <mail@profpatsch.de>
+#                         W. Trevor King <wking@tremily.us>
 #
 # This file is part of rss2email.
 #
@@ -45,8 +46,7 @@ class TimeLimitedFunction (_threading.Thread):
     rss2email.error.TimeoutError: error while running time limited function: a float is required
     """
     def __init__(self, timeout, target, **kwargs):
-        super(TimeLimitedFunction, self).__init__(target=target, **kwargs)
-        self.setDaemon(True)  # daemon kwarg only added in Python 3.3.
+        super(TimeLimitedFunction, self).__init__(target=target, daemon=True, **kwargs)
         self.timeout = timeout
         self.result = None
         self.error = None
